************
Installation
************

Using Pip
=========
.. code-block:: bash

    # Install all the data sources
    pip install 'metadata_guardian[all]'

    # Install one or more data sources from the list
    pip install 'metadata_guardian[snowflake,avro,aws,gcp,deltalake,kafka_schema_registry,mysql]'